@@ -100,33 +100,23 @@ class CoordinationNumber(MDObservable):
 
         self.pbc = pbc
 
-    def _global_configure(self):
-        """Configure the calculation.
+    def _local_configure(self, frame):
+        """Configure the Coordination Number calculus.
 
-        It defines parameters needed for the calculation of CN and the
-        requirements of ctypes.
+        It receive a frame and define the boundary conditions, sets the counter
+        and the ctypes requirements.
         """
-        super()._global_configure()
-
         # pbc = True -> 1; False -> 0 in C code
         self.pbc = 1 if self.pbc else 0
 
         # frame counter
         self.ncn_ = 0
 
-    def _local_configure(self, frame):
-        """To calculate natoms_c_ for ctypes requirements.
-
-        It receive frame.types as `types`. This is not an actually frame
-        accumulation of CN.
-        """
-        types = frame.types
-
         # calculate masks, natoms_c_ and natoms_i_
-        self.mask_c_ = types == self.type_c
-        self.mask_i_ = types == self.type_i
-        self.natoms_c_ = np.count_nonzero(self.mask_c_)
-        self.natoms_i_ = np.count_nonzero(self.mask_i_)
+        self.mask_c_ = frame._mask_type(self.type_c)
+        self.mask_i_ = frame._mask_type(self.type_i)
+        self.natoms_c_ = frame._natoms_type(self.mask_c_)
+        self.natoms_i_ = frame._natoms_type(self.mask_i_)
 
         # ctypes requirements to interact with C code
         lib_cn = ct.CDLL(
