@@ -98,8 +98,8 @@ class AtomicSystem:
         """Tells if the array x is sorted (-> True) or not (-> False)."""
         return (np.diff(self.idx) >= 0).all()
 
-    def _sort_traj(self, dontsort=("natoms", "box")):
-        """Sort all the traj from the sortening of the atoms id."""
+    def _sort_frame(self, dontsort=("natoms", "box")):
+        """Sort the frame from the sortening of the atoms id."""
         id_argsort = np.argsort(self.idx)
 
         for key in self.__dict__.keys():
@@ -113,3 +113,11 @@ class AtomicSystem:
             self.__dict__[key] = self.__dict__[key][id_argsort]
 
         return self
+
+    def _mask_type(self, atom_type):
+        """Get a masked array by an specific type of atom."""
+        return self.types == atom_type
+
+    def _natoms_type(self, mask_type):
+        """Count the number of atoms of an specific type."""
+        return np.count_nonzero(mask_type)
