@@ -48,7 +48,7 @@ class XYZ(TrajectoryReader):
     """
 
     def __init__(self, filename, ftype="xyz"):
-        if ftype not in ["xyz", "property", "image"]:
+        if ftype not in ("xyz", "property", "image"):
             raise ValueError("ftype must be 'xyz', 'property' or 'image'")
 
         super().__init__(filename, ftype)
